@@ -8,7 +8,7 @@ except ImportError:
 register = template.Library()
 
 @register.filter()
-def with_tracking(session, queryset, date_field):
+def with_tracking(queryset, session, date_field=None):
     tracker = ObjectTracker(session)
     for obj in queryset:
         yield obj, tracker.has_viewed(obj, date_field)
\ No newline at end of file
